**********
User Guide
**********

These instructions will provide you detailed instructions on how to use the CEMENTO package. It will go through installation and important considerations into CLI use and basic conversion. A section is also dedicated to scripting for folks looking to integrate CEMENTO into their python-based software. A section on basic drawing also goes through and ins-and-outs of creating ontology diagrams. The links are provided in order for an absolute beginner, but feel free to skip to a relevant section:

Guide Sections
==============
.. toctree::
   :maxdepth: 2

   user-guide-pages/installation
   user-guide-pages/cli-guide
   user-guide-pages/scripting
   user-guide-pages/drawing-basics